all：提供总入口，分析目录中有哪些目标和波段（通过mklist），后续处理的时候提供列表
mklist：分析文件名，并且返回目标波段列表
后续步骤：只需要文件列表和源、目标目录，需要啥文件自动去生成



## `j_all`

这段Python代码定义了一个名为do_all的函数，该函数用于执行一系列的天文数据处理步骤。这个函数基于提供的配置、目录和参数，调用一系列其他的函数来执行不同的数据处理任务。以下是对代码各部分的详细解释：

### 函数定义和参数
函数do_all接受多个参数，其中包括：

ini_file：一个或多个额外的初始化文件（INI文件）。

raw_dir：原始数据目录。

red_dir：处理后的结果目录。

steps：一个字符串，表示要执行的步骤，每个字符代表一个步骤。

obj：要处理的对象名称，如果未指定，则处理所有对象。

band：要处理的波段，如果未指定或为"*"，则处理所有波段。

alt_bias、alt_flat、alt_coord：替代的偏差、平坦和坐标参数。

base_img：基础图像，用于某些处理步骤。

se_cmd：源提取器的命令。

aper：光度测量时使用的孔径。

starxy：星星的x和y坐标列表。

ind_tgt、ind_ref、ind_chk：目标星、参考星和检查星的索引。

mode：工作模式，用于处理文件存在或缺失的情况。

**kwargs：其他额外的配置参数。

### 函数体
函数体主要由一系列条件判断和函数调用组成，根据steps参数中指定的步骤，调用相应的函数来执行处理。

conf = config(...)：创建一个配置对象，用于存储和处理配置参数。

list_all = mklist(...)：创建一个列表，包含所有要处理的对象和波段。

接下来，根据steps参数中的每个步骤字符，执行相应的处理函数：

如果steps中包含"b"，则执行biascomb函数进行偏差组合。

如果steps中包含"f"，则对每个波段执行flatcomb函数进行平坦组合。

然后，对于每个波段和对象，根据steps参数中的步骤字符，执行以下处理：

如果steps中包含"i"，则执行imgcorr函数进行图像校正。

如果steps中包含"o"，则执行offset函数进行偏移处理。

如果steps中包含"p"，则执行phot函数进行光度测量。

如果steps中包含"c"，则执行cata函数收集星星的目录。

如果steps中包含"d"，则执行cali函数进行差分流量/星等校准。

如果steps中包含"g"，则执行graph函数进行图形绘制。

### 总结
这个do_all函数是一个天文数据处理流程的控制函数，它根据提供的配置和参数，调用一系列专门的函数来执行不同的数据处理任务。每个处理任务对应于steps参数中的一个字符，通过这种方式，用户可以灵活地选择需要执行的步骤，以满足不同的数据处理需求。

## q_mlist

这段Python代码定义了一个名为mklist的函数，用于处理特定格式的原始文件，并生成一个包含对象-波段的字典。以下是对代码的详细解释：

函数定义和参数:

conf: 一个配置对象。
raw_dir: 原始文件的目录。
red_dir: 处理后的文件目录。
obj: 要处理的对象，默认为None。
band: 要处理的波段，默认为None。
mode: 输入文件缺失或输出文件存在时的模式，默认为workmode()的一个实例。
save_list_file: 是否保存列表文件或仅返回对象-波段的字典树，默认为True。
内部函数定义:

_filename_parse_: 一个内部函数，用于从文件名中解析出对象、波段和序列号。
文件获取和排序:

使用glob函数从raw_dir目录中获取所有.fit和.fits文件。
获取文件名并排序。
文件名解析:

对每个文件名调用_filename_parse_函数进行解析。
根据解析结果创建objs和bands列表。
处理指定的对象和波段:

如果obj或band被指定，则创建objall和bandall列表，用于后续的筛选。
分发文件:

创建一个名为file_all的字典，用于存储每个波段和对象对应的文件名列表。
创建一个名为list_all的字典，用于存储每个波段对应的对象列表。
遍历文件名、对象和波段，根据指定的objall和bandall进行筛选，并将文件名添加到file_all中。
移除只有flat但没有对象的波段:

遍历file_all，如果某个波段只包含flat而不包含其他对象，则将其从file_all和list_all中删除。
保存列表文件:

如果save_list_file为True，则遍历file_all，为每个对象和波段创建一个列表文件，并保存到red_dir/lst/目录下。
返回值:

函数返回list_all字典，其中键是波段，值是对象列表。
总的来说，这段代码的主要目的是从原始文件目录中解析文件名，提取出对象、波段和序列号信息，然后根据指定的对象和波段进行筛选，最后生成一个包含对象-波段的字典，并可以选择保存为列表文件。

## q_biascomb

这段Python代码定义了一个名为biascomb的函数，用于将多个图像的偏差组合成单个图像。以下是对代码的详细解释：
